@@ -34,23 +34,23 @@
 
 #include "decryptverifytask.h"
 
-#include <Libkleo/CryptoBackendFactory>
-#include <Libkleo/VerifyOpaqueJob>
-#include <Libkleo/VerifyDetachedJob>
-#include <Libkleo/DecryptJob>
-#include <Libkleo/DecryptVerifyJob>
+#include <QGpgME/Protocol>
+#include <QGpgME/VerifyOpaqueJob>
+#include <QGpgME/VerifyDetachedJob>
+#include <QGpgME/DecryptJob>
+#include <QGpgME/DecryptVerifyJob>
+
 #include <Libkleo/Dn>
 #include <Libkleo/Exception>
 #include <Libkleo/Stl_Util>
-
-#include <models/keycache.h>
+#include <Libkleo/KeyCache>
 #include <Libkleo/Predicates>
+#include <Libkleo/Formatting>
+#include <Libkleo/Classify>
 
 #include <utils/detail_p.h>
 #include <utils/input.h>
 #include <utils/output.h>
-#include <utils/classify.h>
-#include <utils/formatting.h>
 #include <utils/kleo_assert.h>
 #include <utils/auditlog.h>
 
@@ -72,8 +72,6 @@
 #include <QStringList>
 #include <QTextDocument> // Qt::escape
 
-#include <boost/bind.hpp>
-
 #include <algorithm>
 #include <cassert>
 #include <sstream>
@@ -81,7 +79,6 @@
 using namespace Kleo::Crypto;
 using namespace Kleo;
 using namespace GpgME;
-using namespace boost;
 using namespace KMime::Types;
 
 namespace
@@ -94,7 +91,7 @@ static Error make_error(const gpg_err_code_t code)
 
 static AuditLog auditLogFromSender(QObject *sender)
 {
-    return AuditLog::fromJob(qobject_cast<const Job *>(sender));
+    return AuditLog::fromJob(qobject_cast<const QGpgME::Job *>(sender));
 }
 
 static bool addrspec_equal(const AddrSpec &lhs, const AddrSpec &rhs, Qt::CaseSensitivity cs)
@@ -177,12 +174,18 @@ static std::vector<Mailbox> extractMailboxes(const std::vector<Key> &signers)
 static bool keyContainsMailbox(const Key &key, const Mailbox &mbox)
 {
     const std::vector<Mailbox> mbxs = extractMailboxes(key);
-    return std::find_if(mbxs.begin(), mbxs.end(), boost::bind(mailbox_equal, mbox, _1, Qt::CaseInsensitive)) != mbxs.end();
+    return std::find_if(mbxs.cbegin(), mbxs.cend(), 
+                        [mbox](const Mailbox &m) {
+                            return mailbox_equal(mbox, m, Qt::CaseInsensitive);
+                        }) != mbxs.cend();
 }
 
 static bool keysContainMailbox(const std::vector<Key> &keys, const Mailbox &mbox)
 {
-    return std::find_if(keys.begin(), keys.end(), boost::bind(keyContainsMailbox, _1, mbox)) != keys.end();
+    return std::find_if(keys.cbegin(), keys.cend(), 
+                        [mbox](const Key &key) {
+                            return keyContainsMailbox(key, mbox);
+                        }) != keys.cend();
 }
 
 static bool relevantInDecryptVerifyContext(const VerificationResult &r)
@@ -376,7 +379,7 @@ public:
     }
     bool hasKeys() const
     {
-        return kdtools::any(signers, !boost::bind(&Key::isNull, _1));
+        return std::any_of(signers.cbegin(), signers.cend(), [](const Key &key) { return !key.isNull(); });
     }
     std::vector<Mailbox> signerMailboxes() const
     {
@@ -430,11 +433,11 @@ static QString formatVerificationResultOverview(const VerificationResult &res, c
         return i18n("<b>No signatures found.</b>");
     }
 
-    const uint bad = std::count_if(sigs.begin(), sigs.end(), IsBad);
+    const uint bad = std::count_if(sigs.cbegin(), sigs.cend(), IsBad);
     if (bad > 0) {
         return i18np("<b>Invalid signature.</b>", "<b>%1 invalid signatures.</b>", bad);
     }
-    const uint warn = std::count_if(sigs.begin(), sigs.end(), !boost::bind(IsGoodOrValid, _1));
+    const uint warn = std::count_if(sigs.cbegin(), sigs.cend(), [](const Signature &sig) { return !IsGoodOrValid(sig); });
     if (warn > 0) {
         return i18np("<b>Not enough information to check signature validity.</b>", "<b>%1 signatures could not be verified.</b>", warn);
     }
@@ -499,7 +502,10 @@ static QString formatSignature(const Signature &sig, const Key &key, const Decry
 static QStringList format(const std::vector<Mailbox> &mbxs)
 {
     QStringList res;
-    std::transform(mbxs.begin(), mbxs.end(), std::back_inserter(res), boost::bind(&Mailbox::prettyAddress, _1));
+    std::transform(mbxs.cbegin(), mbxs.cend(), std::back_inserter(res),
+                   [](const Mailbox &mbox) {
+                       return mbox.prettyAddress();
+                   });
     return res;
 }
 
@@ -646,9 +652,9 @@ DecryptVerifyResult::SenderInfo DecryptVerifyResult::Private::makeSenderInfo() c
     return SenderInfo(m_informativeSender, KeyCache::instance()->findSigners(m_verificationResult));
 }
 
-shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResult(const DecryptionResult &dr, const QByteArray &plaintext, const AuditLog &auditLog)
+std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResult(const DecryptionResult &dr, const QByteArray &plaintext, const AuditLog &auditLog)
 {
-    return shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
+    return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
             Decrypt,
             VerificationResult(),
             dr,
@@ -661,9 +667,9 @@ shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResult(con
             informativeSender()));
 }
 
-shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResult(const GpgME::Error &err, const QString &what, const AuditLog &auditLog)
+std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResult(const GpgME::Error &err, const QString &what, const AuditLog &auditLog)
 {
-    return shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
+    return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
             Decrypt,
             VerificationResult(),
             DecryptionResult(err),
@@ -676,9 +682,9 @@ shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResult(con
             informativeSender()));
 }
 
-shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerifyResult(const DecryptionResult &dr, const VerificationResult &vr, const QByteArray &plaintext, const AuditLog &auditLog)
+std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerifyResult(const DecryptionResult &dr, const VerificationResult &vr, const QByteArray &plaintext, const AuditLog &auditLog)
 {
-    return shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
+    return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
             DecryptVerify,
             vr,
             dr,
@@ -691,9 +697,9 @@ shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerifyResu
             informativeSender()));
 }
 
-shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerifyResult(const GpgME::Error &err, const QString &details, const AuditLog &auditLog)
+std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerifyResult(const GpgME::Error &err, const QString &details, const AuditLog &auditLog)
 {
-    return shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
+    return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
             DecryptVerify,
             VerificationResult(),
             DecryptionResult(err),
@@ -706,9 +712,9 @@ shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerifyResu
             informativeSender()));
 }
 
-shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaqueResult(const VerificationResult &vr, const QByteArray &plaintext, const AuditLog &auditLog)
+std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaqueResult(const VerificationResult &vr, const QByteArray &plaintext, const AuditLog &auditLog)
 {
-    return shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
+    return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
             Verify,
             vr,
             DecryptionResult(),
@@ -720,9 +726,9 @@ shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaqueResul
             auditLog,
             informativeSender()));
 }
-shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaqueResult(const GpgME::Error &err, const QString &details, const AuditLog &auditLog)
+std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaqueResult(const GpgME::Error &err, const QString &details, const AuditLog &auditLog)
 {
-    return shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
+    return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
             Verify,
             VerificationResult(err),
             DecryptionResult(),
@@ -735,9 +741,9 @@ shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaqueResul
             informativeSender()));
 }
 
-shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyDetachedResult(const VerificationResult &vr, const AuditLog &auditLog)
+std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyDetachedResult(const VerificationResult &vr, const AuditLog &auditLog)
 {
-    return shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
+    return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
             Verify,
             vr,
             DecryptionResult(),
@@ -749,9 +755,9 @@ shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyDetachedRes
             auditLog,
             informativeSender()));
 }
-shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyDetachedResult(const GpgME::Error &err, const QString &details, const AuditLog &auditLog)
+std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyDetachedResult(const GpgME::Error &err, const QString &details, const AuditLog &auditLog)
 {
-    return shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
+    return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
             Verify,
             VerificationResult(err),
             DecryptionResult(),
@@ -878,7 +884,7 @@ public:
 
     void slotResult(const DecryptionResult &, const VerificationResult &, const QByteArray &);
 
-    void registerJob(DecryptVerifyJob *job)
+    void registerJob(QGpgME::DecryptVerifyJob *job)
     {
         q->connect(job, SIGNAL(result(GpgME::DecryptionResult,GpgME::VerificationResult,QByteArray)),
                    q, SLOT(slotResult(GpgME::DecryptionResult,GpgME::VerificationResult,QByteArray)));
@@ -886,15 +892,15 @@ public:
                    q, SLOT(setProgress(QString,int,int)));
     }
 
-    void emitResult(const shared_ptr<DecryptVerifyResult> &result);
+    void emitResult(const std::shared_ptr<DecryptVerifyResult> &result);
 
-    shared_ptr<Input> m_input;
-    shared_ptr<Output> m_output;
-    const CryptoBackend::Protocol *m_backend;
+    std::shared_ptr<Input> m_input;
+    std::shared_ptr<Output> m_output;
+    const QGpgME::Protocol *m_backend;
     Protocol m_protocol;
 };
 
-void DecryptVerifyTask::Private::emitResult(const shared_ptr<DecryptVerifyResult> &result)
+void DecryptVerifyTask::Private::emitResult(const std::shared_ptr<DecryptVerifyResult> &result)
 {
     q->emitResult(result);
     Q_EMIT q->decryptVerifyResult(result);
@@ -943,13 +949,13 @@ DecryptVerifyTask::~DecryptVerifyTask()
 {
 }
 
-void DecryptVerifyTask::setInput(const shared_ptr<Input> &input)
+void DecryptVerifyTask::setInput(const std::shared_ptr<Input> &input)
 {
     d->m_input = input;
     kleo_assert(d->m_input && d->m_input->ioDevice());
 }
 
-void DecryptVerifyTask::setOutput(const shared_ptr<Output> &output)
+void DecryptVerifyTask::setOutput(const std::shared_ptr<Output> &output)
 {
     d->m_output = output;
     kleo_assert(d->m_output && d->m_output->ioDevice());
@@ -959,7 +965,7 @@ void DecryptVerifyTask::setProtocol(Protocol prot)
 {
     kleo_assert(prot != UnknownProtocol);
     d->m_protocol = prot;
-    d->m_backend = CryptoBackendFactory::instance()->protocol(prot);
+    d->m_backend = prot == GpgME::OpenPGP ? QGpgME::openpgp() : QGpgME::smime();
     kleo_assert(d->m_backend);
 }
 
@@ -1009,7 +1015,7 @@ void DecryptVerifyTask::doStart()
 {
     kleo_assert(d->m_backend);
     try {
-        DecryptVerifyJob *const job = d->m_backend->decryptVerifyJob();
+        QGpgME::DecryptVerifyJob *const job = d->m_backend->decryptVerifyJob();
         kleo_assert(job);
         d->registerJob(job);
         job->start(d->m_input->ioDevice(), d->m_output->ioDevice());
@@ -1031,7 +1037,7 @@ public:
 
     void slotResult(const DecryptionResult &, const QByteArray &);
 
-    void registerJob(DecryptJob *job)
+    void registerJob(QGpgME::DecryptJob *job)
     {
         q->connect(job, SIGNAL(result(GpgME::DecryptionResult,QByteArray)),
                    q, SLOT(slotResult(GpgME::DecryptionResult,QByteArray)));
@@ -1039,15 +1045,15 @@ public:
                    q, SLOT(setProgress(QString,int,int)));
     }
 
-    void emitResult(const shared_ptr<DecryptVerifyResult> &result);
+    void emitResult(const std::shared_ptr<DecryptVerifyResult> &result);
 
-    shared_ptr<Input> m_input;
-    shared_ptr<Output> m_output;
-    const CryptoBackend::Protocol *m_backend;
+    std::shared_ptr<Input> m_input;
+    std::shared_ptr<Output> m_output;
+    const QGpgME::Protocol *m_backend;
     Protocol m_protocol;
 };
 
-void DecryptTask::Private::emitResult(const shared_ptr<DecryptVerifyResult> &result)
+void DecryptTask::Private::emitResult(const std::shared_ptr<DecryptVerifyResult> &result)
 {
     q->emitResult(result);
     Q_EMIT q->decryptVerifyResult(result);
@@ -1097,13 +1103,13 @@ DecryptTask::~DecryptTask()
 {
 }
 
-void DecryptTask::setInput(const shared_ptr<Input> &input)
+void DecryptTask::setInput(const std::shared_ptr<Input> &input)
 {
     d->m_input = input;
     kleo_assert(d->m_input && d->m_input->ioDevice());
 }
 
-void DecryptTask::setOutput(const shared_ptr<Output> &output)
+void DecryptTask::setOutput(const std::shared_ptr<Output> &output)
 {
     d->m_output = output;
     kleo_assert(d->m_output && d->m_output->ioDevice());
@@ -1113,7 +1119,7 @@ void DecryptTask::setProtocol(Protocol prot)
 {
     kleo_assert(prot != UnknownProtocol);
     d->m_protocol = prot;
-    d->m_backend = CryptoBackendFactory::instance()->protocol(prot);
+    d->m_backend = (prot == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
     kleo_assert(d->m_backend);
 }
 
@@ -1165,7 +1171,7 @@ void DecryptTask::doStart()
     kleo_assert(d->m_backend);
 
     try {
-        DecryptJob *const job = d->m_backend->decryptJob();
+        QGpgME::DecryptJob *const job = d->m_backend->decryptJob();
         kleo_assert(job);
         d->registerJob(job);
         job->start(d->m_input->ioDevice(), d->m_output->ioDevice());
@@ -1186,7 +1192,7 @@ public:
 
     void slotResult(const VerificationResult &, const QByteArray &);
 
-    void registerJob(VerifyOpaqueJob *job)
+    void registerJob(QGpgME::VerifyOpaqueJob *job)
     {
         q->connect(job, SIGNAL(result(GpgME::VerificationResult,QByteArray)),
                    q, SLOT(slotResult(GpgME::VerificationResult,QByteArray)));
@@ -1194,15 +1200,15 @@ public:
                    q, SLOT(setProgress(QString,int,int)));
     }
 
-    void emitResult(const shared_ptr<DecryptVerifyResult> &result);
+    void emitResult(const std::shared_ptr<DecryptVerifyResult> &result);
 
-    shared_ptr<Input> m_input;
-    shared_ptr<Output> m_output;
-    const CryptoBackend::Protocol *m_backend;
+    std::shared_ptr<Input> m_input;
+    std::shared_ptr<Output> m_output;
+    const QGpgME::Protocol *m_backend;
     Protocol m_protocol;
 };
 
-void VerifyOpaqueTask::Private::emitResult(const shared_ptr<DecryptVerifyResult> &result)
+void VerifyOpaqueTask::Private::emitResult(const std::shared_ptr<DecryptVerifyResult> &result)
 {
     q->emitResult(result);
     Q_EMIT q->decryptVerifyResult(result);
@@ -1252,13 +1258,13 @@ VerifyOpaqueTask::~VerifyOpaqueTask()
 {
 }
 
-void VerifyOpaqueTask::setInput(const shared_ptr<Input> &input)
+void VerifyOpaqueTask::setInput(const std::shared_ptr<Input> &input)
 {
     d->m_input = input;
     kleo_assert(d->m_input && d->m_input->ioDevice());
 }
 
-void VerifyOpaqueTask::setOutput(const shared_ptr<Output> &output)
+void VerifyOpaqueTask::setOutput(const std::shared_ptr<Output> &output)
 {
     d->m_output = output;
     kleo_assert(d->m_output && d->m_output->ioDevice());
@@ -1268,7 +1274,7 @@ void VerifyOpaqueTask::setProtocol(Protocol prot)
 {
     kleo_assert(prot != UnknownProtocol);
     d->m_protocol = prot;
-    d->m_backend = CryptoBackendFactory::instance()->protocol(prot);
+    d->m_backend = (prot == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
     kleo_assert(d->m_backend);
 }
 
@@ -1319,10 +1325,10 @@ void VerifyOpaqueTask::doStart()
     kleo_assert(d->m_backend);
 
     try {
-        VerifyOpaqueJob *const job = d->m_backend->verifyOpaqueJob();
+        QGpgME::VerifyOpaqueJob *const job = d->m_backend->verifyOpaqueJob();
         kleo_assert(job);
         d->registerJob(job);
-        job->start(d->m_input->ioDevice(), d->m_output ? d->m_output->ioDevice() : shared_ptr<QIODevice>());
+        job->start(d->m_input->ioDevice(), d->m_output ? d->m_output->ioDevice() : std::shared_ptr<QIODevice>());
     } catch (const GpgME::Exception &e) {
         d->emitResult(fromVerifyOpaqueResult(e.error(), QString::fromLocal8Bit(e.what()), AuditLog()));
     } catch (const std::exception &e) {
@@ -1340,7 +1346,7 @@ public:
 
     void slotResult(const VerificationResult &);
 
-    void registerJob(VerifyDetachedJob *job)
+    void registerJob(QGpgME::VerifyDetachedJob *job)
     {
         q->connect(job, SIGNAL(result(GpgME::VerificationResult)),
                    q, SLOT(slotResult(GpgME::VerificationResult)));
@@ -1348,14 +1354,14 @@ public:
                    q, SLOT(setProgress(QString,int,int)));
     }
 
-    void emitResult(const shared_ptr<DecryptVerifyResult> &result);
+    void emitResult(const std::shared_ptr<DecryptVerifyResult> &result);
 
-    shared_ptr<Input> m_input, m_signedData;
-    const CryptoBackend::Protocol *m_backend;
+    std::shared_ptr<Input> m_input, m_signedData;
+    const QGpgME::Protocol *m_backend;
     Protocol m_protocol;
 };
 
-void VerifyDetachedTask::Private::emitResult(const shared_ptr<DecryptVerifyResult> &result)
+void VerifyDetachedTask::Private::emitResult(const std::shared_ptr<DecryptVerifyResult> &result)
 {
     q->emitResult(result);
     Q_EMIT q->decryptVerifyResult(result);
@@ -1389,13 +1395,13 @@ VerifyDetachedTask::~VerifyDetachedTask()
 {
 }
 
-void VerifyDetachedTask::setInput(const shared_ptr<Input> &input)
+void VerifyDetachedTask::setInput(const std::shared_ptr<Input> &input)
 {
     d->m_input = input;
     kleo_assert(d->m_input && d->m_input->ioDevice());
 }
 
-void VerifyDetachedTask::setSignedData(const shared_ptr<Input> &signedData)
+void VerifyDetachedTask::setSignedData(const std::shared_ptr<Input> &signedData)
 {
     d->m_signedData = signedData;
     kleo_assert(d->m_signedData && d->m_signedData->ioDevice());
@@ -1405,7 +1411,7 @@ void VerifyDetachedTask::setProtocol(Protocol prot)
 {
     kleo_assert(prot != UnknownProtocol);
     d->m_protocol = prot;
-    d->m_backend = CryptoBackendFactory::instance()->protocol(prot);
+    d->m_backend = (prot == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
     kleo_assert(d->m_backend);
 }
 
@@ -1472,7 +1478,7 @@ void VerifyDetachedTask::doStart()
 {
     kleo_assert(d->m_backend);
     try {
-        VerifyDetachedJob *const job = d->m_backend->verifyDetachedJob();
+        QGpgME::VerifyDetachedJob *const job = d->m_backend->verifyDetachedJob();
         kleo_assert(job);
         d->registerJob(job);
         job->start(d->m_input->ioDevice(), d->m_signedData->ioDevice());
